api.documents.v1.customer package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.customer package

## Submodules

## api.documents.v1.customer.customer module

Autogenerated API

`api.documents.v1.customer.customer.` `get_customer_root_folder`(customerID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch customer root folder (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – ID of customer to fetch root folder for
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 977, “limit”: 44, “responseCode”: 200, “count”: 817, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Suffer assume how explain south ball.”, “messageTemplate”: “Debate across late particularly.”, “field”: “East why memory week this again open.”, “parameter”: {}, “timestamp”: 356262952}], “currentPage”: 963, “size”: 175}

## Module contents